@@ -108,16 +108,33 @@ class KubeModel(ABC):
         self.logger.debug(f"Configure optimizer at epoch: {self.epoch}")
 
 
+    # def _load_optimizer_state(self):
+    #     """
+    #     Checks for a previously saved state of the optimizer and loads it
+    #     """
+    #     if os.path.isfile('opt.pkl'):
+    #         self.logger.debug('Loading optimizer state')
+    #         with open('opt.pkl', 'rb') as f:
+    #             self.logger.debug('Loading optimizer state, epoch: {self.epoch}')
+    #             state = pickle.load(f)
+    #             self.optimizer.load_state_dict(state)
+
+
     def _load_optimizer_state(self):
         """
-        Checks for a previously saved state of the optimizer and loads it
+        Saves the optimizer state to be loaded again in
+        the following epochs
         """
-        if os.path.isfile('opt.pkl'):
-            self.logger.debug('Loading optimizer state')
-            with open('opt.pkl', 'rb') as f:
-                self.logger.debug('Loading optimizer state, epoch: {self.epoch}')
+        job_id = self.args._job_id
+        func_id = self.args._func_id
+        if os.path.isfile(f'/output/{job_id}:opt:{func_id}.pkl'):
+            self.logger.debug(f'loading optimizer file from host, path: /output/{job_id}:opt:{func_id}.pkl')
+            with open(f'/output/{job_id}:opt:{func_id}.pkl', 'rb') as f:
+                self.logger.debug(f'loading optimizer file, epoch: {self.epoch}')
                 state = pickle.load(f)
                 self.optimizer.load_state_dict(state)
+                self.logger.debug('optimizer file loaded')
+                print('optimizer file loaded') 
 
     def _reset_optimizer_state(self):
         """
@@ -128,18 +145,33 @@ class KubeModel(ABC):
         if self.optimizer is not None:
             self.optimizer.state = defaultdict(dict)
 
+    # def _save_optimizer_state(self):
+    #     """
+    #     Saves the optimizer state to be loaded again in
+    #     the following epochs
+    #     """
+        
+    #     self.logger.debug('saving optimizer state')
+
+    #     with open('opt.pkl', 'wb') as f:
+    #         self.logger.debug('saving optimizer state, epoch: {self.epoch}')
+    #         pickle.dump(self.optimizer.state_dict(), f)
+    #     print('saved state')
+
     def _save_optimizer_state(self):
         """
         Saves the optimizer state to be loaded again in
         the following epochs
         """
-        
-        self.logger.debug('saving optimizer state')
+        job_id = self.args._job_id
+        func_id = self.args._func_id
+        self.logger.debug('saving optimizer file to host')
 
-        with open('opt.pkl', 'wb') as f:
-            self.logger.debug('saving optimizer state, epoch: {self.epoch}')
+        with open(f'/output/{job_id}:opt:{func_id}.pkl', 'wb') as f:
+            self.logger.debug(f'saving optimizer file to path: /output/{job_id}:opt:{func_id}.pkl , epoch: {self.epoch}')
             pickle.dump(self.optimizer.state_dict(), f)
-        print('saved state')
+            self.logger.debug('optimizer file saved')
+        print('optimizer file saved')   
 
     def _save_file_test(self):
         """
@@ -323,9 +355,10 @@ class KubeModel(ABC):
         :return:
         """
         self.__load_model()
-        self._load_optimizer_redis()
-        self._load_redis_test()
-        self._load_file_test()
+        # self._load_optimizer_redis()
+        # self._load_redis_test()
+        # self._load_file_test()
+        self._load_optimizer_state()
 
         #self._load_optimizer_state()
 
@@ -337,10 +370,10 @@ class KubeModel(ABC):
         :return:
         """
         self.__save_model()
-        self._save_optimizer_redis()
-        self._save_redis_test()
-        self._save_file_test()
-        #self._save_optimizer_state()
+        # self._save_optimizer_redis()
+        # self._save_redis_test()
+        # self._save_file_test()
+        self._save_optimizer_state()
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
         """
